@@ -123,6 +123,9 @@ class AnalysisDirectory:
     def get_root(self) -> str:
         return self._path.path()
 
+    def get_root_path(self) -> SearchPathElement:
+        return self._path
+
     def get_filter_roots(self) -> Set[str]:
         current_project_directories = self._filter_paths or {self.get_root()}
         return {
@@ -246,6 +249,9 @@ class SharedAnalysisDirectory(AnalysisDirectory):
     def get_root(self) -> str:
         return self.get_command_line_root()
 
+    def get_root_path(self) -> SearchPathElement:
+        return SimpleSearchPathElement(self.get_root())
+
     def get_filter_roots(self) -> Set[str]:
         current_project_directories = self._filter_paths or {self._project_root}
         if len(self._targets) == 0:
@@ -553,8 +559,20 @@ class SharedAnalysisDirectory(AnalysisDirectory):
         if absolute_link_map is None:
             relative_link_map = {}
             try:
+                configuration = self._configuration
+                buck_mode = (
+                    configuration.buck_mode if configuration is not None else None
+                )
+                isolation_prefix = (
+                    configuration.isolation_prefix
+                    if configuration is not None
+                    else None
+                )
                 relative_link_map = buck.query_buck_relative_paths(
-                    new_paths, self._targets
+                    new_paths,
+                    self._targets,
+                    buck_mode=buck_mode,
+                    isolation_prefix=isolation_prefix,
                 )
             except buck.BuckException as error:
                 LOG.error("Exception occurred when querying buck: %s", error)
@@ -763,15 +781,15 @@ def _get_project_name(
 
 
 def _get_buck_builder(
-    project_root: str,
     configuration: Configuration,
-    buck_mode: Optional[str],
     relative_local_root: Optional[str],
     isolate: bool,
 ) -> Tuple[BuckBuilder, List[str]]:
     if not configuration.use_buck_builder:
         return (buck.SimpleBuckBuilder(), [])
 
+    project_root = configuration.project_root
+    buck_mode = configuration.buck_mode
     buck_root = find_buck_root(project_root)
     if not buck_root:
         raise EnvironmentException(
@@ -814,9 +832,7 @@ def resolve_analysis_directory(
     targets: List[str],
     configuration: Configuration,
     original_directory: str,
-    project_root: str,
     filter_directory: Optional[str],
-    buck_mode: Optional[str],
     isolate: bool = False,
     relative_local_root: Optional[str] = None,
 ) -> AnalysisDirectory:
@@ -853,6 +869,7 @@ def resolve_analysis_directory(
             command,
         )
 
+    project_root = configuration.project_root
     local_configuration_root = configuration.local_root
     if local_configuration_root:
         local_configuration_root = os.path.relpath(
@@ -870,7 +887,7 @@ def resolve_analysis_directory(
         )
     else:
         buck_builder, temporary_directories = _get_buck_builder(
-            project_root, configuration, buck_mode, relative_local_root, isolate
+            configuration, relative_local_root, isolate
         )
 
         analysis_directory = SharedAnalysisDirectory(
