@@ -47,17 +47,23 @@ class CommandArguments:
     saved_state_project: Optional[str] = None
     dot_pyre_directory: Optional[Path] = None
     features: Optional[str] = None
-    use_command_v2: bool = False
+    use_command_v2: Optional[bool] = None
     isolation_prefix: Optional[str] = None
+    python_version: Optional[str] = None
 
 
 @dataclass(frozen=True)
 class StartArguments:
     changed_files_path: Optional[str] = None
     debug: bool = False
+    enable_memory_profiling: bool = False
+    enable_profiling: bool = False
     load_initial_state_from: Optional[str] = None
+    log_identifier: Optional[str] = None
+    logging_sections: Optional[str] = None
     no_saved_state: bool = False
     no_watchman: bool = False
+    noninteractive: bool = False
     save_initial_state_to: Optional[str] = None
     saved_state_project: Optional[str] = None
     sequential: bool = False
@@ -72,3 +78,9 @@ class IncrementalArguments:
     output: str = TEXT
     no_start: bool = False
     start_arguments: StartArguments = field(default_factory=StartArguments)
+
+
+@dataclass(frozen=True)
+class RageArguments:
+    output: Optional[Path] = None
+    server_log_count: Optional[int] = None
