@@ -63,6 +63,7 @@ class ProfileOutput(enum.Enum):
     TRACE_EVENT: str = "trace_event"
     COLD_START_PHASES: str = "cold_start_phases"
     INCREMENTAL_UPDATES: str = "incremental_updates"
+    TAINT: str = "taint"
     INDIVIDUAL_TABLE_SIZES: str = "individual_table_sizes"
     TOTAL_SHARED_MEMORY_SIZE_OVER_TIME: str = "total_shared_memory_size_over_time"
     TOTAL_SHARED_MEMORY_SIZE_OVER_TIME_GRAPH: str = (
@@ -186,9 +187,7 @@ class Command(CommandParser, ABC):
             self._command_arguments.targets,
             self._configuration,
             self._original_directory,
-            self._configuration.project_root,
             filter_directory=self._command_arguments.filter_directory,
-            buck_mode=self._command_arguments.buck_mode,
             relative_local_root=self._configuration.relative_local_root,
         )
 
