@@ -3,17 +3,16 @@
 # This source code is licensed under the MIT license found in the
 # LICENSE file in the root directory of this source tree.
 
-import argparse
 import dataclasses
 import json
 import logging
 from pathlib import Path
 from typing import List, NamedTuple, Optional
 
-from .. import command_arguments, log
+from .. import command_arguments, configuration as configuration_module, log
 from ..analysis_directory import AnalysisDirectory
 from ..configuration import Configuration
-from .command import JSON, Command
+from .command import Command
 from .stop import Stop
 
 
@@ -66,35 +65,6 @@ class Servers(Command):
         )
         self._subcommand = subcommand
 
-    @staticmethod
-    def from_arguments(
-        arguments: argparse.Namespace,
-        original_directory: str,
-        configuration: Configuration,
-        analysis_directory: Optional[AnalysisDirectory] = None,
-    ) -> "Servers":
-        return Servers(
-            command_arguments.CommandArguments.from_arguments(arguments),
-            original_directory,
-            configuration=configuration,
-            analysis_directory=analysis_directory,
-            subcommand=arguments.servers_subcommand,
-        )
-
-    @classmethod
-    def add_subparser(cls, parser: argparse._SubParsersAction) -> None:
-        servers_parser = parser.add_parser(
-            cls.NAME,
-            epilog="""
-            Command to manipulate multiple Pyre servers.
-            """,
-        )
-        servers_parser.set_defaults(command=cls.from_arguments)
-        subparsers = servers_parser.add_subparsers(dest="servers_subcommand")
-
-        subparsers.add_parser("list", help="List running servers.")
-        subparsers.add_parser("stop", help="Stop all running servers.")
-
     def is_root_server_running(self) -> bool:
         return any(server.is_root() for server in self._all_server_details())
 
@@ -102,7 +72,7 @@ class Servers(Command):
     def _print_server_details(
         all_server_details: List[ServerDetails], output_format: str
     ) -> None:
-        if output_format == JSON:
+        if output_format == command_arguments.JSON:
             server_details = [
                 {"pid": details.pid, "name": details.name}
                 for details in all_server_details
@@ -133,7 +103,7 @@ class Servers(Command):
     def _stop_servers(self, servers: List[ServerDetails]) -> None:
         for server in servers:
             LOG.warning("Stopping server for `%s` with pid %d", server.name, server.pid)
-            local_configuration = Configuration.from_arguments(
+            local_configuration = configuration_module.create_configuration(
                 dataclasses.replace(
                     self._command_arguments, local_configuration=server.local_root
                 ),
