@@ -5,6 +5,8 @@
 
 
 import json
+import logging
+import time
 from pathlib import Path
 from typing import Any, Dict, List, Mapping, Optional, Set, Type, Union
 
@@ -24,6 +26,8 @@ from ..statistics_collectors import (
 )
 from .command import Command
 
+LOG: logging.Logger = logging.getLogger(__name__)
+
 
 def _get_paths(target_directory: Path) -> List[Path]:
     return [
@@ -61,17 +65,20 @@ def _parse_paths(paths: List[Path]) -> List[Path]:
 def _path_wise_counts(
     paths: Mapping[str, Union[cst.Module, cst.MetadataWrapper]],
     collector_class: Type[StatisticsCollector],
-    strict: bool = False,
+    strict_by_default: bool = False,
 ) -> Dict[str, StatisticsCollector]:
     collected_counts = {}
     for path, module in paths.items():
         collector = (
-            StrictCountCollector(strict)
+            StrictCountCollector(strict_by_default)
             if collector_class == StrictCountCollector
             else collector_class()
         )
-        module.visit(collector)
-        collected_counts[str(path)] = collector
+        try:
+            module.visit(collector)
+            collected_counts[str(path)] = collector
+        except RecursionError:
+            LOG.warning(f"LibCST encountered recursion error in `{path}`")
     return collected_counts
 
 
@@ -131,6 +138,8 @@ class Statistics(Command):
         }
 
     def _run(self) -> None:
+        log_identifier = self._command_arguments.log_identifier
+        run_id = log_identifier if log_identifier is not None else str(time.time_ns())
         paths = self._find_paths()
         modules = {}
         for path in _parse_paths(paths):
@@ -140,32 +149,31 @@ class Statistics(Command):
         data = self._collect_statistics(modules)
         log.stdout.write(json.dumps(data, indent=4))
         if self._log_results:
-            self._log_to_scuba(data)
+            self._log_to_scuba(run_id, data)
 
-    def _log_to_scuba(self, data: Dict[str, Any]) -> None:
+    def _log_to_scuba(self, run_id: str, data: Dict[str, Any]) -> None:
         if self._configuration and self._configuration.logger:
-            root = str(self._configuration.relative_local_root)
             for path, counts in data["annotations"].items():
                 statistics.log_with_configuration(
                     statistics.LoggerCategory.ANNOTATION_COUNTS,
                     configuration=self._configuration,
                     integers=counts,
-                    normals={"root": root, "path": path},
+                    normals={"run_id": run_id, "path": path},
                 )
             for path, counts in data["fixmes"].items():
-                self._log_fixmes("fixme", counts, root, path)
+                self._log_fixmes(run_id, "fixme", counts, path)
             for path, counts in data["ignores"].items():
-                self._log_fixmes("ignore", counts, root, path)
+                self._log_fixmes(run_id, "ignore", counts, path)
             for path, counts in data["strict"].items():
                 statistics.log_with_configuration(
                     statistics.LoggerCategory.STRICT_ADOPTION,
                     configuration=self._configuration,
                     integers=counts,
-                    normals={"root": root, "path": path},
+                    normals={"run_id": run_id, "path": path},
                 )
 
     def _log_fixmes(
-        self, fixme_type: str, data: Dict[str, int], root: str, path: str
+        self, run_id: str, fixme_type: str, data: Dict[str, int], path: str
     ) -> None:
         for error_code, count in data.items():
             statistics.log_with_configuration(
@@ -173,7 +181,7 @@ class Statistics(Command):
                 configuration=self._configuration,
                 integers={"count": count},
                 normals={
-                    "root": root,
+                    "run_id": run_id,
                     "code": error_code,
                     "type": fixme_type,
                     "path": path,
