@@ -4,9 +4,12 @@
 # LICENSE file in the root directory of this source tree.
 
 from . import incremental  # noqa F401
+from . import kill  # noqa F401
 from . import persistent  # noqa F401
 from . import query  # noqa F401
+from . import rage  # noqa F401
 from . import restart  # noqa F401
+from . import servers  # noqa F401
 from . import start  # noqa F401
 from . import stop  # noqa F401
 from . import validate_models  # noqa F401
