@@ -7,31 +7,19 @@ import logging
 from pathlib import Path
 
 from ... import command_arguments, commands, configuration as configuration_module
-from . import incremental, server_connection, start, stop
+from . import incremental, stop, remote_logging
 
 
 LOG: logging.Logger = logging.getLogger(__name__)
 
 
-def _stop_server_if_needed(configuration: configuration_module.Configuration) -> None:
-    try:
-        socket_path = server_connection.get_default_socket_path(
-            log_directory=Path(configuration.log_directory)
-        )
-        LOG.info("Stopping the server if needed...")
-        stop.stop_server(socket_path)
-        LOG.info(f"Stopped server at `{start.get_server_identifier(configuration)}`")
-    except server_connection.ConnectionFailure:
-        # This usually means there's no server running
-        pass
-
-
+@remote_logging.log_usage(command_name="restart")
 def run(
     configuration: configuration_module.Configuration,
     incremental_arguments: command_arguments.IncrementalArguments,
 ) -> commands.ExitCode:
     try:
-        _stop_server_if_needed(configuration)
+        stop.run_stop(configuration)
         incremental.run_incremental(configuration, incremental_arguments)
         return commands.ExitCode.SUCCESS
     except Exception as error:
