@@ -93,11 +93,20 @@ class InvalidConfiguration(Exception):
         super().__init__(self.message)
 
 
+class InvalidPythonVersion(InvalidConfiguration):
+    def __init__(self, message: str) -> None:
+        super().__init__(message)
+
+
 class SearchPathElement(abc.ABC):
     @abc.abstractmethod
     def path(self) -> str:
         raise NotImplementedError
 
+    @abc.abstractmethod
+    def get_root(self) -> str:
+        raise NotImplementedError
+
     @abc.abstractmethod
     def command_line_argument(self) -> str:
         raise NotImplementedError
@@ -118,6 +127,9 @@ class SimpleSearchPathElement(SearchPathElement):
     def path(self) -> str:
         return self.root
 
+    def get_root(self) -> str:
+        return self.root
+
     def command_line_argument(self) -> str:
         return self.root
 
@@ -140,6 +152,9 @@ class SubdirectorySearchPathElement(SearchPathElement):
     def path(self) -> str:
         return os.path.join(self.root, self.subdirectory)
 
+    def get_root(self) -> str:
+        return self.root
+
     def command_line_argument(self) -> str:
         return self.root + "$" + self.subdirectory
 
@@ -164,6 +179,9 @@ class SitePackageSearchPathElement(SearchPathElement):
     def path(self) -> str:
         return os.path.join(self.site_root, self.package_name)
 
+    def get_root(self) -> str:
+        return self.site_root
+
     def command_line_argument(self) -> str:
         return self.site_root + "$" + self.package_name
 
@@ -263,11 +281,41 @@ def _in_virtual_environment(override: Optional[bool] = None) -> bool:
     return sys.prefix != sys.base_prefix
 
 
+@dataclass(frozen=True)
+class PythonVersion:
+    major: int
+    minor: int = 0
+    micro: int = 0
+
+    @staticmethod
+    def from_string(input: str) -> "PythonVersion":
+        try:
+            splits = input.split(".")
+            if len(splits) == 1:
+                return PythonVersion(major=int(splits[0]))
+            elif len(splits) == 2:
+                return PythonVersion(major=int(splits[0]), minor=int(splits[1]))
+            elif len(splits) == 3:
+                return PythonVersion(
+                    major=int(splits[0]), minor=int(splits[1]), micro=int(splits[2])
+                )
+            raise InvalidPythonVersion(
+                "Version string is expected to have the form of 'X.Y.Z' but got "
+                + f"'{input}'"
+            )
+        except ValueError as error:
+            raise InvalidPythonVersion(str(error))
+
+    def to_string(self) -> str:
+        return f"{self.major}.{self.minor}.{self.micro}"
+
+
 @dataclass(frozen=True)
 class PartialConfiguration:
     autocomplete: Optional[bool] = None
     binary: Optional[str] = None
     buck_builder_binary: Optional[str] = None
+    buck_mode: Optional[str] = None
     disabled: Optional[bool] = None
     do_not_ignore_all_errors_in: Sequence[str] = field(default_factory=list)
     dot_pyre_directory: Optional[Path] = None
@@ -281,6 +329,7 @@ class PartialConfiguration:
     logger: Optional[str] = None
     number_of_workers: Optional[int] = None
     other_critical_files: Sequence[str] = field(default_factory=list)
+    python_version: Optional[PythonVersion] = None
     search_path: Sequence[SearchPathElement] = field(default_factory=list)
     source_directories: Optional[Sequence[SearchPathElement]] = None
     strict: Optional[bool] = None
@@ -289,6 +338,7 @@ class PartialConfiguration:
     typeshed: Optional[str] = None
     use_buck_builder: Optional[bool] = None
     use_buck_source_database: Optional[bool] = None
+    use_command_v2: Optional[bool] = None
     version_hash: Optional[str] = None
 
     @staticmethod
@@ -298,7 +348,7 @@ class PartialConfiguration:
     @staticmethod
     def _get_extra_keys() -> Set[str]:
         return {
-            "buck_mode",
+            "accept_command_v2",
             "create_open_source_configuration",
             "differential",
             "oncall",
@@ -319,10 +369,12 @@ class PartialConfiguration:
         targets: Optional[List[str]] = (
             arguments.targets if len(arguments.targets) > 0 else None
         )
+        python_version_string = arguments.python_version
         return PartialConfiguration(
             autocomplete=None,
             binary=arguments.binary,
             buck_builder_binary=arguments.buck_builder_binary,
+            buck_mode=arguments.buck_mode,
             disabled=None,
             do_not_ignore_all_errors_in=[],
             dot_pyre_directory=arguments.dot_pyre_directory,
@@ -336,6 +388,11 @@ class PartialConfiguration:
             logger=arguments.logger,
             number_of_workers=None,
             other_critical_files=[],
+            python_version=(
+                PythonVersion.from_string(python_version_string)
+                if python_version_string is not None
+                else None
+            ),
             search_path=[
                 SimpleSearchPathElement(element) for element in arguments.search_path
             ],
@@ -346,6 +403,7 @@ class PartialConfiguration:
             typeshed=arguments.typeshed,
             use_buck_builder=arguments.use_buck_builder,
             use_buck_source_database=arguments.use_buck_source_database,
+            use_command_v2=arguments.use_command_v2,
             version_hash=None,
         )
 
@@ -429,6 +487,17 @@ class PartialConfiguration:
                     search_path_json, site_roots=_get_site_roots()
                 )
 
+            python_version_json = configuration_json.pop("python_version", None)
+            if python_version_json is None:
+                python_version = None
+            elif isinstance(python_version_json, str):
+                python_version = PythonVersion.from_string(python_version_json)
+            else:
+                raise InvalidConfiguration(
+                    "Expect python version to be a string but got"
+                    + f"'{python_version_json}'"
+                )
+
             source_directories_json = ensure_option_type(
                 configuration_json, "source_directories", list
             )
@@ -451,6 +520,7 @@ class PartialConfiguration:
                 buck_builder_binary=ensure_option_type(
                     configuration_json, "buck_builder_binary", str
                 ),
+                buck_mode=ensure_option_type(configuration_json, "buck_mode", str),
                 disabled=ensure_option_type(configuration_json, "disabled", bool),
                 do_not_ignore_all_errors_in=ensure_string_list(
                     configuration_json, "do_not_ignore_errors_in"
@@ -481,6 +551,7 @@ class PartialConfiguration:
                 other_critical_files=ensure_string_list(
                     configuration_json, "critical_files"
                 ),
+                python_version=python_version,
                 search_path=search_path,
                 source_directories=source_directories,
                 strict=ensure_option_type(configuration_json, "strict", bool),
@@ -495,6 +566,9 @@ class PartialConfiguration:
                 use_buck_source_database=ensure_option_type(
                     configuration_json, "use_buck_source_database", bool
                 ),
+                use_command_v2=ensure_option_type(
+                    configuration_json, "use_command_v2", bool
+                ),
                 version_hash=ensure_option_type(configuration_json, "version", str),
             )
 
@@ -551,6 +625,7 @@ class PartialConfiguration:
             autocomplete=self.autocomplete,
             binary=binary,
             buck_builder_binary=buck_builder_binary,
+            buck_mode=self.buck_mode,
             disabled=self.disabled,
             do_not_ignore_all_errors_in=[
                 expand_relative_path(root, path)
@@ -573,6 +648,7 @@ class PartialConfiguration:
             other_critical_files=[
                 expand_relative_path(root, path) for path in self.other_critical_files
             ],
+            python_version=self.python_version,
             search_path=[path.expand_relative_root(root) for path in self.search_path],
             source_directories=source_directories,
             strict=self.strict,
@@ -583,6 +659,7 @@ class PartialConfiguration:
             typeshed=typeshed,
             use_buck_builder=self.use_buck_builder,
             use_buck_source_database=self.use_buck_source_database,
+            use_command_v2=self.use_command_v2,
             version_hash=self.version_hash,
         )
 
@@ -614,6 +691,7 @@ def merge_partial_configurations(
         buck_builder_binary=overwrite_base(
             base.buck_builder_binary, override.buck_builder_binary
         ),
+        buck_mode=overwrite_base(base.buck_mode, override.buck_mode),
         disabled=overwrite_base(base.disabled, override.disabled),
         do_not_ignore_all_errors_in=prepend_base(
             base.do_not_ignore_all_errors_in, override.do_not_ignore_all_errors_in
@@ -639,6 +717,7 @@ def merge_partial_configurations(
         other_critical_files=prepend_base(
             base.other_critical_files, override.other_critical_files
         ),
+        python_version=overwrite_base(base.python_version, override.python_version),
         search_path=prepend_base(base.search_path, override.search_path),
         source_directories=raise_when_overridden(
             base.source_directories,
@@ -657,6 +736,7 @@ def merge_partial_configurations(
         use_buck_source_database=overwrite_base(
             base.use_buck_source_database, override.use_buck_source_database
         ),
+        use_command_v2=overwrite_base(base.use_command_v2, override.use_command_v2),
         version_hash=overwrite_base(base.version_hash, override.version_hash),
     )
 
@@ -669,6 +749,7 @@ class Configuration:
     autocomplete: bool = False
     binary: Optional[str] = None
     buck_builder_binary: Optional[str] = None
+    buck_mode: Optional[str] = None
     disabled: bool = False
     do_not_ignore_all_errors_in: Sequence[str] = field(default_factory=list)
     excludes: Sequence[str] = field(default_factory=list)
@@ -681,6 +762,7 @@ class Configuration:
     logger: Optional[str] = None
     number_of_workers: Optional[int] = None
     other_critical_files: Sequence[str] = field(default_factory=list)
+    python_version: Optional[PythonVersion] = None
     relative_local_root: Optional[str] = None
     search_path: Sequence[SearchPathElement] = field(default_factory=list)
     source_directories: Sequence[SearchPathElement] = field(default_factory=list)
@@ -690,6 +772,7 @@ class Configuration:
     typeshed: Optional[str] = None
     use_buck_builder: bool = False
     use_buck_source_database: bool = False
+    use_command_v2: bool = False
     version_hash: Optional[str] = None
 
     @staticmethod
@@ -714,6 +797,7 @@ class Configuration:
             ),
             binary=partial_configuration.binary,
             buck_builder_binary=partial_configuration.buck_builder_binary,
+            buck_mode=partial_configuration.buck_mode,
             disabled=_get_optional_value(partial_configuration.disabled, default=False),
             do_not_ignore_all_errors_in=partial_configuration.do_not_ignore_all_errors_in,
             excludes=partial_configuration.excludes,
@@ -726,6 +810,7 @@ class Configuration:
             logger=partial_configuration.logger,
             number_of_workers=partial_configuration.number_of_workers,
             other_critical_files=partial_configuration.other_critical_files,
+            python_version=partial_configuration.python_version,
             relative_local_root=relative_local_root,
             search_path=[
                 path.expand_global_root(str(project_root)) for path in search_path
@@ -743,6 +828,9 @@ class Configuration:
             use_buck_source_database=_get_optional_value(
                 partial_configuration.use_buck_source_database, default=False
             ),
+            use_command_v2=_get_optional_value(
+                partial_configuration.use_command_v2, default=False
+            ),
             version_hash=partial_configuration.version_hash,
         )
 
@@ -758,6 +846,70 @@ class Configuration:
             return None
         return os.path.join(self.project_root, self.relative_local_root)
 
+    def to_json(self) -> Dict[str, object]:
+        """
+        This method is for display purpose only. Do *NOT* expect this method
+        to produce JSONs that can be de-serialized back into configurations.
+        """
+        binary = self.binary
+        buck_builder_binary = self.buck_builder_binary
+        buck_mode = self.buck_mode
+        formatter = self.formatter
+        isolation_prefix = self.isolation_prefix
+        logger = self.logger
+        number_of_workers = self.number_of_workers
+        python_version = self.python_version
+        relative_local_root = self.relative_local_root
+        typeshed = self.typeshed
+        version_hash = self.version_hash
+        return {
+            "global_root": self.project_root,
+            "dot_pyre_directory": str(self.dot_pyre_directory),
+            "autocomplete": self.autocomplete,
+            **({"binary": binary} if binary is not None else {}),
+            **(
+                {"buck_builder_binary": buck_builder_binary}
+                if buck_builder_binary is not None
+                else {}
+            ),
+            **({"buck_mode": buck_mode} if buck_mode is not None else {}),
+            "disabled": self.disabled,
+            "do_not_ignore_all_errors_in": list(self.do_not_ignore_all_errors_in),
+            "excludes": list(self.excludes),
+            "extensions": list(self.extensions),
+            **({"formatter": formatter} if formatter is not None else {}),
+            "ignore_all_errors": list(self.ignore_all_errors),
+            "ignore_infer": list(self.ignore_infer),
+            **(
+                {"isolation_prefix": isolation_prefix}
+                if isolation_prefix is not None
+                else {}
+            ),
+            **({"logger": logger} if logger is not None else {}),
+            **({"workers": number_of_workers} if number_of_workers is not None else {}),
+            "other_critical_files": list(self.other_critical_files),
+            **(
+                {"python_version": python_version.to_string()}
+                if python_version is not None
+                else {}
+            ),
+            **(
+                {"relative_local_root": relative_local_root}
+                if relative_local_root is not None
+                else {}
+            ),
+            "search_path": [path.path() for path in self.search_path],
+            "source_directories": [path.path() for path in self.source_directories],
+            "strict": self.strict,
+            "taint_models_path": list(self.taint_models_path),
+            "targets": list(self.targets),
+            **({"typeshed": typeshed} if typeshed is not None else {}),
+            "use_buck_builder": self.use_buck_builder,
+            "use_buck_source_database": self.use_buck_source_database,
+            "use_command_v2": self.use_command_v2,
+            **({"version_hash": version_hash} if version_hash is not None else {}),
+        }
+
     def get_existent_source_directories(self) -> List[SearchPathElement]:
         return self._get_existent_paths(self.source_directories)
 
@@ -919,6 +1071,18 @@ class Configuration:
         override `isolation_prefix` as `""` in a local configuration."""
         return None if self.isolation_prefix == "" else self.isolation_prefix
 
+    def get_python_version(self) -> PythonVersion:
+        python_version = self.python_version
+        if python_version is not None:
+            return python_version
+        else:
+            version_info = sys.version_info
+            return PythonVersion(
+                major=version_info.major,
+                minor=version_info.minor,
+                micro=version_info.micro,
+            )
+
 
 def create_configuration(
     arguments: command_arguments.CommandArguments, base_directory: Path
