@@ -11,6 +11,7 @@ import os
 import shutil
 import subprocess
 from contextlib import contextmanager
+from pathlib import Path
 from typing import ContextManager, Dict, Generator, Iterable, List, Optional, Set
 
 from .exceptions import EnvironmentException
@@ -65,11 +66,11 @@ def translate_path(root: str, path: str) -> str:
 
 
 def expand_relative_path(root: str, path: str) -> str:
-    path = os.path.expanduser(path)
-    if os.path.isabs(path):
-        return path
+    expanded_path = Path(path).expanduser()
+    if expanded_path.is_absolute():
+        return str(expanded_path)
     else:
-        return os.path.join(root, path)
+        return str(Path(root) / expanded_path)
 
 
 def translate_paths(paths: Set[str], original_directory: str) -> Set[str]:
@@ -88,6 +89,12 @@ def exists(path: str) -> str:
     return path
 
 
+def file_or_directory_exists(path: str) -> str:
+    if os.path.isdir(path) or os.path.isfile(path):
+        return path
+    raise ValueError("%s is not a valid path" % path)
+
+
 def is_parent(parent: str, child: str) -> bool:
     return child.startswith(parent.rstrip(os.sep) + os.sep)
 
@@ -161,13 +168,13 @@ def _compute_symbolic_link_mapping(
     directory: str, extensions: Iterable[str]
 ) -> Dict[str, str]:
     """
-        Given a shared analysis directory, produce a mapping from actual source files
-        to files contained within this directory. Only includes files which have
-        one of the provided extensions.
+    Given a shared analysis directory, produce a mapping from actual source files
+    to files contained within this directory. Only includes files which have
+    one of the provided extensions.
 
-        Watchman watches actual source files, so when a change is detected to a
-        file, this mapping can be used to identify what file changed from Pyre's
-        perspective.
+    Watchman watches actual source files, so when a change is detected to a
+    file, this mapping can be used to identify what file changed from Pyre's
+    perspective.
     """
     symbolic_links = {}
     try:
@@ -257,12 +264,12 @@ class Filesystem:
         self, root: str, patterns: List[str], exclude: Optional[List[str]] = None
     ) -> List[str]:
         """
-            Return the list of files that match any of the patterns within root.
-            If exclude is provided, files that match an exclude pattern are omitted.
+        Return the list of files that match any of the patterns within root.
+        If exclude is provided, files that match an exclude pattern are omitted.
 
-            Note: The `find` command does not understand globs properly.
-                e.g. 'a/*.py' will match 'a/b/c.py'
-            For this reason, avoid calling this method with glob patterns.
+        Note: The `find` command does not understand globs properly.
+            e.g. 'a/*.py' will match 'a/b/c.py'
+        For this reason, avoid calling this method with glob patterns.
         """
 
         command = ["find", "."]
