@@ -44,7 +44,7 @@ def _log_statistics(
     exit_code: int,
 ) -> None:
     configuration = command.configuration
-    if configuration and configuration.logger:
+    if configuration is not None:
         statistics_module.log_with_configuration(
             category=statistics_module.LoggerCategory.USAGE,
             configuration=configuration,
@@ -53,8 +53,6 @@ def _log_statistics(
                 "runtime": int((time.time() - start_time) * 1000),
             },
             normals={
-                "project_root": configuration.project_root,
-                "root": configuration.relative_local_root,
                 "cwd": os.getcwd(),
                 "client_version": __version__,
                 "command_line": " ".join(sys.argv),
@@ -109,8 +107,7 @@ def run_pyre_command(
     # from exception flows.
     exit_code = ExitCode.FAILURE
     try:
-        configuration_module.check_nested_local_configuration(configuration)
-        configuration_module.check_open_source_version(configuration)
+        _check_configuration(configuration)
         log.start_logging_to_directory(noninteractive, configuration.log_directory)
         LOG.debug(f"Running cli command `{' '.join(sys.argv)}`...")
         exit_code = command.run().exit_code()
@@ -167,13 +164,22 @@ def _run_incremental_command(
     no_watchman: bool,
 ) -> ExitCode:
     configuration = _create_configuration_with_retry(arguments, Path("."))
-    if arguments.use_command_v2:
+    if configuration.use_command_v2:
+        _check_configuration(configuration)
+        log.start_logging_to_directory(
+            arguments.noninteractive, configuration.log_directory
+        )
         start_arguments = command_arguments.StartArguments(
             changed_files_path=arguments.changed_files_path,
             debug=arguments.debug,
+            enable_memory_profiling=arguments.enable_memory_profiling,
+            enable_profiling=arguments.enable_profiling,
             load_initial_state_from=arguments.load_initial_state_from,
+            log_identifier=arguments.log_identifier,
+            logging_sections=arguments.logging_sections,
             no_saved_state=arguments.no_saved_state,
             no_watchman=no_watchman,
+            noninteractive=arguments.noninteractive,
             save_initial_state_to=arguments.save_initial_state_to,
             saved_state_project=arguments.saved_state_project,
             sequential=arguments.sequential,
@@ -226,6 +232,25 @@ def _run_default_command(arguments: command_arguments.CommandArguments) -> ExitC
         return _run_check_command(arguments)
 
 
+def _run_servers_list_command(
+    arguments: command_arguments.CommandArguments,
+) -> ExitCode:
+    if arguments.use_command_v2:
+        return v2.servers.run_list()
+    else:
+        configuration = configuration_module.create_configuration(arguments, Path("."))
+        return run_pyre_command(
+            commands.Servers(
+                arguments,
+                original_directory=os.getcwd(),
+                configuration=configuration,
+                subcommand="list",
+            ),
+            configuration,
+            arguments.noninteractive,
+        )
+
+
 def _create_configuration_with_retry(
     arguments: command_arguments.CommandArguments, base_directory: Path
 ) -> configuration_module.Configuration:
@@ -268,7 +293,15 @@ def _create_configuration_with_retry(
     raise configuration_module.InvalidConfiguration(error_message)
 
 
-@click.group(invoke_without_command=True)
+def _check_configuration(configuration: configuration_module.Configuration) -> None:
+    configuration_module.check_nested_local_configuration(configuration)
+    configuration_module.check_open_source_version(configuration)
+
+
+@click.group(
+    invoke_without_command=True,
+    context_settings={"help_option_names": ["-h", "--help"]},
+)
 @click.pass_context
 @click.option(
     "-l",
@@ -381,8 +414,18 @@ def _create_configuration_with_retry(
 @click.option("--changed-files-path", type=str, hidden=True)
 @click.option("--saved-state-project", type=str, hidden=True)
 @click.option("--features", type=str, hidden=True)
-@click.option("--use-command-v2", is_flag=True, default=False, hidden=True)
+@click.option("--use-command-v2", is_flag=True, default=None, hidden=True)
 @click.option("--isolation-prefix", type=str, hidden=True)
+@click.option(
+    "--python-version",
+    type=str,
+    help=(
+        "Specify the version of Python in which the codebase is written."
+        " Pyre recognizes version string in the form of 'X.Y.Z'."
+        " By default, the Python version used to run `pyre` itself is used."
+    ),
+    hidden=True,
+)
 def pyre(
     context: click.Context,
     local_configuration: Optional[str],
@@ -418,8 +461,9 @@ def pyre(
     changed_files_path: Optional[str],
     saved_state_project: Optional[str],
     features: Optional[str],
-    use_command_v2: bool,
+    use_command_v2: Optional[bool],
     isolation_prefix: Optional[str],
+    python_version: Optional[str],
 ) -> int:
     arguments = command_arguments.CommandArguments(
         local_configuration=local_configuration,
@@ -459,6 +503,7 @@ def pyre(
         features=features,
         use_command_v2=use_command_v2,
         isolation_prefix=isolation_prefix,
+        python_version=python_version,
     )
     if arguments.version:
         _show_pyre_version(arguments)
@@ -744,16 +789,19 @@ def kill(context: click.Context, with_fire: bool) -> int:
     configuration = configuration_module.create_configuration(
         command_argument, Path(".")
     )
-    return run_pyre_command(
-        commands.Kill(
-            command_argument,
-            original_directory=os.getcwd(),
-            configuration=configuration,
-            with_fire=with_fire,
-        ),
-        configuration,
-        command_argument.noninteractive,
-    )
+    if configuration.use_command_v2:
+        return v2.kill.run(configuration, with_fire)
+    else:
+        return run_pyre_command(
+            commands.Kill(
+                command_argument,
+                original_directory=os.getcwd(),
+                configuration=configuration,
+                with_fire=with_fire,
+            ),
+            configuration,
+            command_argument.noninteractive,
+        )
 
 
 @pyre.command()
@@ -769,18 +817,25 @@ def persistent(context: click.Context, no_watchman: bool) -> int:
     configuration = configuration_module.create_configuration(
         command_argument, Path(".")
     )
-    if command_argument.use_command_v2:
+    if configuration.use_command_v2:
         log.start_logging_to_directory(
-            command_argument.noninteractive, configuration.log_directory
+            # Always log to file regardless of whether `-n` is given
+            noninteractive=False,
+            log_directory=configuration.log_directory,
         )
         return v2.persistent.run(
             configuration,
             command_arguments.StartArguments(
                 changed_files_path=command_argument.changed_files_path,
                 debug=command_argument.debug,
+                enable_memory_profiling=command_argument.enable_memory_profiling,
+                enable_profiling=command_argument.enable_profiling,
                 load_initial_state_from=command_argument.load_initial_state_from,
+                log_identifier=command_argument.log_identifier,
+                logging_sections=command_argument.logging_sections,
                 no_saved_state=command_argument.no_saved_state,
                 no_watchman=no_watchman,
+                noninteractive=command_argument.noninteractive,
                 save_initial_state_to=command_argument.save_initial_state_to,
                 saved_state_project=command_argument.saved_state_project,
                 sequential=command_argument.sequential,
@@ -851,7 +906,10 @@ def query(context: click.Context, query: str) -> int:
     command_argument: command_arguments.CommandArguments = context.obj["arguments"]
     configuration = _create_configuration_with_retry(command_argument, Path("."))
 
-    if command_argument.use_command_v2:
+    if configuration.use_command_v2:
+        log.start_logging_to_directory(
+            command_argument.noninteractive, configuration.log_directory
+        )
         return v2.query.run(configuration, query)
     else:
         return run_pyre_command(
@@ -872,8 +930,16 @@ def query(context: click.Context, query: str) -> int:
     type=os.path.abspath,
     help="The path to the output file (defaults to stdout)",
 )
+@click.option(
+    "--server-log-count",
+    type=int,
+    default=3,
+    help="Number of server logs to include in the diagnositics. Default to 3.",
+)
 @click.pass_context
-def rage(context: click.Context, output_file: str) -> int:
+def rage(
+    context: click.Context, output_file: Optional[str], server_log_count: int
+) -> int:
     """
     Collects troubleshooting diagnostics for Pyre, and writes this information
     to the terminal or to a file.
@@ -882,16 +948,26 @@ def rage(context: click.Context, output_file: str) -> int:
     configuration = configuration_module.create_configuration(
         command_argument, Path(".")
     )
-    return run_pyre_command(
-        commands.Rage(
-            command_argument,
-            original_directory=os.getcwd(),
-            configuration=configuration,
-            output_path=output_file,
-        ),
-        configuration,
-        command_argument.noninteractive,
-    )
+
+    if configuration.use_command_v2:
+        return v2.rage.run(
+            configuration,
+            command_arguments.RageArguments(
+                output=Path(output_file) if output_file is not None else None,
+                server_log_count=server_log_count,
+            ),
+        )
+    else:
+        return run_pyre_command(
+            commands.Rage(
+                command_argument,
+                original_directory=os.getcwd(),
+                configuration=configuration,
+                output_path=output_file,
+            ),
+            configuration,
+            command_argument.noninteractive,
+        )
 
 
 @pyre.command()
@@ -934,13 +1010,22 @@ def restart(
     """
     command_argument: command_arguments.CommandArguments = context.obj["arguments"]
     configuration = _create_configuration_with_retry(command_argument, Path("."))
-    if command_argument.use_command_v2:
+    if configuration.use_command_v2:
+        _check_configuration(configuration)
+        log.start_logging_to_directory(
+            command_argument.noninteractive, configuration.log_directory
+        )
         start_arguments = command_arguments.StartArguments(
             changed_files_path=command_argument.changed_files_path,
             debug=command_argument.debug,
+            enable_memory_profiling=command_argument.enable_memory_profiling,
+            enable_profiling=command_argument.enable_profiling,
             load_initial_state_from=command_argument.load_initial_state_from,
+            log_identifier=command_argument.log_identifier,
+            logging_sections=command_argument.logging_sections,
             no_saved_state=command_argument.no_saved_state,
             no_watchman=no_watchman,
+            noninteractive=command_argument.noninteractive,
             save_initial_state_to=command_argument.save_initial_state_to,
             saved_state_project=command_argument.saved_state_project,
             sequential=command_argument.sequential,
@@ -975,33 +1060,52 @@ def restart(
         )
 
 
-@pyre.command()
-@click.argument("subcommand", type=click.Choice(["list", "stop"]), default="list")
+@pyre.group(
+    invoke_without_command=True,
+)
 @click.pass_context
-def servers(context: click.Context, subcommand: str) -> int:
+def servers(context: click.Context) -> int:
     """
-    Command to manipulate multiple Pyre servers.
+    Commands to manipulate multiple Pyre servers.
+    """
+    if context.invoked_subcommand is None:
+        return _run_servers_list_command(context.obj["arguments"])
+    # This return value is not used anywhere.
+    return ExitCode.SUCCESS
 
-    Supported subcommands:
 
-    - `list`: List running servers.
+@servers.command(name="list")
+@click.pass_context
+def servers_list(context: click.Context) -> int:
+    """
+    List all running servers.
+    """
+    return _run_servers_list_command(context.obj["arguments"])
 
-    - `stop`: Stop all running servers.
+
+@servers.command(name="stop")
+@click.pass_context
+def servers_stop(context: click.Context) -> int:
+    """
+    Stop all running servers.
     """
     command_argument: command_arguments.CommandArguments = context.obj["arguments"]
-    configuration = configuration_module.create_configuration(
-        command_argument, Path(".")
-    )
-    return run_pyre_command(
-        commands.Servers(
-            command_argument,
-            original_directory=os.getcwd(),
-            configuration=configuration,
-            subcommand=subcommand,
-        ),
-        configuration,
-        command_argument.noninteractive,
-    )
+    if command_argument.use_command_v2:
+        return v2.servers.run_stop()
+    else:
+        configuration = configuration_module.create_configuration(
+            command_argument, Path(".")
+        )
+        return run_pyre_command(
+            commands.Servers(
+                command_argument,
+                original_directory=os.getcwd(),
+                configuration=configuration,
+                subcommand="stop",
+            ),
+            configuration,
+            command_argument.noninteractive,
+        )
 
 
 @pyre.command()
@@ -1051,15 +1155,24 @@ def start(
     """
     command_argument: command_arguments.CommandArguments = context.obj["arguments"]
     configuration = _create_configuration_with_retry(command_argument, Path("."))
-    if command_argument.use_command_v2:
+    if configuration.use_command_v2:
+        _check_configuration(configuration)
+        log.start_logging_to_directory(
+            command_argument.noninteractive, configuration.log_directory
+        )
         return v2.start.run(
             configuration,
             command_arguments.StartArguments(
                 changed_files_path=command_argument.changed_files_path,
                 debug=command_argument.debug,
+                enable_memory_profiling=command_argument.enable_memory_profiling,
+                enable_profiling=command_argument.enable_profiling,
                 load_initial_state_from=command_argument.load_initial_state_from,
+                log_identifier=command_argument.log_identifier,
+                logging_sections=command_argument.logging_sections,
                 no_saved_state=command_argument.no_saved_state,
                 no_watchman=no_watchman,
+                noninteractive=command_argument.noninteractive,
                 save_initial_state_to=command_argument.save_initial_state_to,
                 saved_state_project=command_argument.saved_state_project,
                 sequential=command_argument.sequential,
@@ -1128,7 +1241,10 @@ def stop(context: click.Context) -> int:
     configuration = configuration_module.create_configuration(
         command_argument, Path(".")
     )
-    if command_argument.use_command_v2:
+    if configuration.use_command_v2:
+        log.start_logging_to_directory(
+            command_argument.noninteractive, configuration.log_directory
+        )
         return v2.stop.run(configuration)
     else:
         return run_pyre_command(
@@ -1151,7 +1267,10 @@ def validate_models(context: click.Context) -> int:
     command_argument: command_arguments.CommandArguments = context.obj["arguments"]
     configuration = _create_configuration_with_retry(command_argument, Path("."))
 
-    if command_argument.use_command_v2:
+    if configuration.use_command_v2:
+        log.start_logging_to_directory(
+            command_argument.noninteractive, configuration.log_directory
+        )
         return v2.validate_models.run(configuration, output=command_argument.output)
     else:
         return run_pyre_command(
