@@ -12,7 +12,7 @@ from typing_extensions import Final
 
 from ..configuration import Configuration
 from ..errors import Errors
-from ..filesystem import LocalMode, add_local_mode, find_files
+from ..filesystem import LocalMode, add_local_mode, find_files, path_exists
 from ..repository import Repository
 from .command import CommandArguments, ErrorSuppressingCommand
 
@@ -26,11 +26,11 @@ class ExpandTargetCoverage(ErrorSuppressingCommand):
         command_arguments: CommandArguments,
         *,
         repository: Repository,
-        subdirectory: Optional[str],
+        local_configuration: Optional[str],
         fixme_threshold: bool,
     ) -> None:
         super().__init__(command_arguments, repository)
-        self._subdirectory: Final[Optional[str]] = subdirectory
+        self._local_configuration: Final[Optional[str]] = local_configuration
         self._fixme_threshold: bool = fixme_threshold
 
     @staticmethod
@@ -41,16 +41,21 @@ class ExpandTargetCoverage(ErrorSuppressingCommand):
         return ExpandTargetCoverage(
             command_arguments,
             repository=repository,
-            subdirectory=arguments.subdirectory,
+            local_configuration=arguments.local_configuration,
             fixme_threshold=arguments.fixme_threshold,
         )
 
     @classmethod
+    # pyre-fixme[40]: Non-static method `add_arguments` cannot override a static
+    #  method defined in `ErrorSuppressingCommand`.
     def add_arguments(cls, parser: argparse.ArgumentParser) -> None:
         super(ExpandTargetCoverage, cls).add_arguments(parser)
         parser.set_defaults(command=cls.from_arguments)
         parser.add_argument(
-            "--subdirectory", help="Only upgrade TARGETS files within this directory."
+            "-l",
+            "--local-configuration",
+            type=path_exists,
+            help="Path to project root with local configuration",
         )
         parser.add_argument(
             "--fixme-threshold",
@@ -59,13 +64,13 @@ class ExpandTargetCoverage(ErrorSuppressingCommand):
         )
 
     def run(self) -> None:
-        subdirectory = self._subdirectory
-        subdirectory = Path(subdirectory) if subdirectory else Path.cwd()
+        local_root = self._local_configuration
+        local_root = Path(local_root) if local_root else Path.cwd()
 
         # Do not change if configurations exist below given root
-        existing_configurations = find_files(subdirectory, ".pyre_configuration.local")
+        existing_configurations = find_files(local_root, ".pyre_configuration.local")
         if existing_configurations and not existing_configurations == [
-            str(subdirectory / ".pyre_configuration.local")
+            str(local_root / ".pyre_configuration.local")
         ]:
             LOG.warning(
                 "Cannot expand targets because nested configurations exist:\n%s",
@@ -74,13 +79,13 @@ class ExpandTargetCoverage(ErrorSuppressingCommand):
             return
 
         # Expand coverage
-        local_configuration = Configuration.find_local_configuration(subdirectory)
+        local_configuration = Configuration.find_local_configuration(local_root)
         if not local_configuration:
             LOG.warning("Could not find a local configuration to codemod.")
             return
         LOG.info("Expanding typecheck targets in `%s`", local_configuration)
         configuration = Configuration(local_configuration)
-        configuration.add_targets(["//" + str(subdirectory) + "/..."])
+        configuration.add_targets(["//" + str(local_root) + "/..."])
         configuration.deduplicate_targets()
         configuration.write()
 
@@ -109,7 +114,7 @@ class ExpandTargetCoverage(ErrorSuppressingCommand):
 
         self._repository.commit_changes(
             commit=(not self._no_commit),
-            title=f"Expand target type coverage in {subdirectory}",
+            title=f"Expand target type coverage in {local_root}",
             summary="Expanding type coverage of targets in configuration.",
             set_dependencies=False,
         )
