@@ -44,8 +44,8 @@ class Configuration:
         self.version: Optional[str] = json_contents.get("version")
         self.differential: bool = json_contents.get("differential", False)
         self.use_buck_builder: Optional[bool] = json_contents.get("use_buck_builder")
-        self.use_buck_source_database: Optional[bool] = (
-            json_contents.get("use_buck_source_database")
+        self.use_buck_source_database: Optional[bool] = json_contents.get(
+            "use_buck_source_database"
         )
 
     def get_contents(self) -> Dict[str, Any]:
@@ -169,38 +169,41 @@ class Configuration:
             self.targets = targets
 
     def deduplicate_targets(self) -> None:
-        all_targets = self.targets
-        if all_targets:
-            all_targets = sorted(set(all_targets))
-            deduplicated_targets = []
-            expanded_targets = set()
-            for target in all_targets:
-                if target.endswith("/...") or target.endswith(":"):
-                    try:
-                        expanded = (
-                            subprocess.check_output(["buck", "query", target])
-                            .decode()
-                            .strip()
-                            .split("\n")
-                        )
-                        if not all(target in expanded_targets for target in expanded):
-                            expanded_targets.update(expanded)
-                            deduplicated_targets.append(target)
-                    except subprocess.CalledProcessError as error:
-                        LOG.warning(
-                            "Failed to query target: %s\n%s", target, str(error)
-                        )
+        targets = self.targets
+        if not targets:
+            return
+        glob_targets = [target for target in targets if target.endswith("/...")]
+        non_glob_targets = [target for target in targets if not target.endswith("/...")]
+        all_targets = sorted(set(glob_targets)) + sorted(set(non_glob_targets))
+        deduplicated_targets = []
+        expanded_targets = set()
+        for target in all_targets:
+            if target.endswith("/...") or target.endswith(":"):
+                try:
+                    expanded = (
+                        subprocess.check_output(["buck", "query", target])
+                        .decode()
+                        .strip()
+                        .split("\n")
+                    )
+                    if not all(target in expanded_targets for target in expanded):
+                        expanded_targets.update(expanded)
                         deduplicated_targets.append(target)
-                elif target not in expanded_targets:
-                    expanded_targets.add(target)
+                except subprocess.CalledProcessError as error:
+                    LOG.warning("Failed to query target: %s\n%s", target, str(error))
                     deduplicated_targets.append(target)
-            self.targets = deduplicated_targets
+            elif target not in expanded_targets:
+                expanded_targets.add(target)
+                deduplicated_targets.append(target)
+        deduplicated_targets.sort(key=lambda target: targets.index(target))
+        self.targets = deduplicated_targets
 
     def run_pyre(
         self,
         arguments: List[str],
         description: str,
         should_clean: bool,
+        command_input: Optional[str],
         stderr_flag: subprocess._FILE = subprocess.PIPE,
     ) -> Optional[subprocess.CompletedProcess[str]]:
         if should_clean:
@@ -221,23 +224,29 @@ class Configuration:
                 stdout=subprocess.PIPE,
                 stderr=stderr_flag,
                 text=True,
+                input=command_input,
             )
         except subprocess.CalledProcessError as error:
             LOG.warning("Error calling pyre: %s", str(error))
             return None
 
     def get_errors(
-        self, only_fix_error_code: Optional[int] = None, should_clean: bool = True
+        self,
+        only_fix_error_code: Optional[int] = None,
+        should_clean: bool = True,
+        command_input: Optional[str] = None,
+        strict: bool = False,
     ) -> Errors:
-        arguments = (
-            ["-l", self.root, "--output=json", "check"]
-            if self.is_local
-            else ["--output=json", "check"]
+        local_root_arguments = (
+            ["--local-configuration", self.root] if self.is_local else []
         )
+        strict_arguments = ["--strict"] if strict else []
+        arguments = [*strict_arguments, *local_root_arguments, "--output=json", "check"]
         pyre_output = self.run_pyre(
             arguments=arguments,
             description=f"Checking `{self.root}`...",
             should_clean=self.targets is not None and should_clean,
+            command_input=command_input,
         )
         if not pyre_output:
             return Errors.empty()
