@@ -456,7 +456,7 @@ def _suppress_errors(
     truncate: bool = False,
     unsafe: bool = False,
 ) -> str:
-    if "@" "generated" in input:
+    if not unsafe and "@" "generated" in input:
         raise SkippingGeneratedFileException()
 
     lines: List[str] = input.split("\n")
