@@ -16,16 +16,17 @@ from .commands.codemods import (
     EnableSourceDatabaseBuckBuilder,
     MissingGlobalAnnotations,
     MissingOverrideReturnAnnotations,
-    SupportSqlalchemy,
 )
 from .commands.consolidate_nested_configurations import ConsolidateNestedConfigurations
 from .commands.expand_target_coverage import ExpandTargetCoverage
+from .commands.fix_configuration import FixConfiguration
 from .commands.fixme import Fixme
 from .commands.fixme_all import FixmeAll
 from .commands.fixme_single import FixmeSingle
 from .commands.fixme_targets import FixmeTargets
 from .commands.global_version_update import GlobalVersionUpdate
 from .commands.strict_default import StrictDefault
+from .commands.support_sqlalchemy import SupportSqlalchemy
 from .commands.targets_to_configuration import TargetsToConfiguration
 from .repository import Repository
 
@@ -91,6 +92,10 @@ def run(repository: Repository) -> None:
     consolidate_nested_configurations = commands.add_parser("consolidate-nested")
     ConsolidateNestedConfigurations.add_arguments(consolidate_nested_configurations)
 
+    # Subcommand: Attempt remediation on broken configuration.
+    fix_configuration = commands.add_parser("fix-configuration")
+    FixConfiguration.add_arguments(fix_configuration)
+
     enable_source_database_buck_builder = commands.add_parser(
         "enable-source-database-buck-builder"
     )
